# python 3 support
from __future__ import absolute_import, print_function, division

import os
import platform

if platform.system() != "Windows":
    import pwd
else:
    import getpass

def get_current_username():
    if platform.system() != "Windows":
        return pwd.getpwuid(os.getuid())[0]
    else:
        return getpass.getuser()



# Copyright (c) 2013 Spotify AB
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

import logging

from snakebite.commandlineparser import CommandLineParser

log = logging.getLogger(__name__)


class SnakebiteCli(object):
    def __init__(self):
        clparser = CommandLineParser()
        self.args = clparser.parse()
        self._setup_logging()
        clparser.init()
        clparser.execute()

    def _setup_logging(self):
        if self.args.debug:
            loglevel = logging.DEBUG
        else:
            loglevel = logging.INFO
        logging.basicConfig(level=loglevel)

SnakebiteCli()



# -*- coding: utf-8 -*-
# Copyright (c) 2013 Spotify AB
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# python 3 support
from __future__ import absolute_import, print_function, division

class Namenode(object):
    '''Namenode class - represents HDFS namenode'''
    DEFAULT_PORT = 8020
    DEFAULT_VERSION = 9

    def __init__(self, host, port=DEFAULT_PORT, version=DEFAULT_VERSION):
        self.host = host
        self.port = port
        self.version = version

    def is_active(self):
        return True

    def toDict(self):
        return {"namenode": self.host,
                "port": self.port,
                "version": self.version}



# -*- coding: utf-8 -*-
# Copyright (c) 2013 Spotify AB
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# python 3 support
from __future__ import absolute_import, print_function, division

import os
import subprocess
import select
import re
import datetime
from snakebite.compat import long


class MiniCluster(object):
    ''' Class that spawns a hadoop mini cluster and wrap hadoop functionality

    This class requires the ``HADOOP_HOME`` environment variable to be set to run the ``hadoop`` command.
    It will search ``HADOOP_HOME`` for ``hadoop-mapreduce-client-jobclient<version>-tests.jar``, but the
    location of this jar can also be supplied by the ``HADOOP_JOBCLIENT_JAR`` environment variable.

    Since the current minicluster interface doesn't provide for specifying the namenode post number, and
    chooses a random one, this class parses the output from the minicluster to find the port numer.

    All supplied methods (like :py:func:`put`, :py:func:`ls`, etc) use the hadoop command to perform operations, and not
    the snakebite client, since this is used for testing snakebite itself.

    All methods return a list of maps that are snakebite compatible.

    Example without :mod:`snakebite.client <client>`

    >>> from snakebite.minicluster import MiniCluster
    >>> cluster = MiniCluster("/path/to/test/files")
    >>> ls_output = cluster.ls(["/"])

    Example with :mod:`snakebite.client <client>`

    >>> from snakebite.minicluster import MiniCluster
    >>> from snakebite.client import Client
    >>> cluster = MiniCluster("/path/to/test/files")
    >>> client = Client('localhost', cluster.port)
    >>> ls_output = client.ls(["/"])

    Just as the snakebite client, the cluster methods take a list of strings as paths. Wherever a method
    takes ``extra_args``, normal hadoop command arguments can be given (like -r, -f, etc).

    More info can be found at http://hadoop.apache.org/docs/current/hadoop-project-dist/hadoop-common/CLIMiniCluster.html

    .. note:: A minicluster will be started at instantiation
    .. note:: Not all hadoop commands have been implemented, only the ones that
              were necessary for testing the snakebite client, but please feel free to add them
    '''
    def __init__(self, testfiles_path, start_cluster=True, nnport=None):
        '''
        :param testfiles_path: Local path where test files can be found. Mainly used for ``put()``
        :type testfiles_path: string
        :param start_cluster: start a MiniCluster on initialization. If False, this class will act as an interface to the ``hadoop fs`` command
        :type start_cluster: boolean
        '''
        self._testfiles_path = testfiles_path
        self._hadoop_home = os.environ['HADOOP_HOME']
        self._jobclient_jar = os.environ.get('HADOOP_JOBCLIENT_JAR')
        self._hadoop_cmd = "%s/bin/hadoop" % self._hadoop_home
        if start_cluster:
            self._start_mini_cluster(nnport)
            self.host = "localhost"
            self.port = self._get_namenode_port()
            self.hdfs_url = "hdfs://%s:%d" % (self.host, self.port)
        else:
            self.hdfs_url = "hdfs://"

    def terminate(self):
        ''' Terminate the cluster

        Since the minicluster is started as a subprocess, this method has to be called explicitely when
        your program ends.
        '''
        self.hdfs.terminate()

    def put(self, src, dst):
        '''Upload a file to HDFS

        This will take a file from the ``testfiles_path`` supplied in the constuctor.
        '''
        src = "%s%s" % (self._testfiles_path, src)
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-put', src, self._full_hdfs_path(dst)], True)

    def put_subprocess(self, src, dst, block_size=134217728, text=True):  # This is used for testing with large files.
        block_size_flag = "-Ddfs.block.size=%s" % str(block_size)
        cmd = [self._hadoop_cmd, 'fs', block_size_flag, '-put', src, self._full_hdfs_path(dst)]
        return subprocess.Popen(cmd, bufsize=0, stdout=subprocess.PIPE, stderr=subprocess.PIPE, stdin=subprocess.PIPE, universal_newlines=text)

    def exists(self, path):
        """Return True if <src> exists, False if doesn't"""
        return self._getReturnCodeCmd([self._hadoop_cmd, 'fs', '-test', '-e', path]) == 0

    def is_directory(self, path):
        """Return True if <path> is a directory, False if it's NOT a directory"""
        return self._getReturnCodeCmd([self._hadoop_cmd, 'fs', '-test', '-d', self._full_hdfs_path(path)]) == 0

    def is_files(self, path):
        """Return True if <path> is a file, False if it's NOT a file"""
        return self._getReturnCodeCmd([self._hadoop_cmd, 'fs', '-test', '-f', self._full_hdfs_path(path)]) == 0

    def is_greater_then_zero_bytes(self, path):
        """Return True if file <path> is greater than zero bytes in size, False otherwise"""
        return self._getReturnCodeCmd([self._hadoop_cmd, 'fs', '-test', '-s', self._full_hdfs_path(path)]) == 0

    def is_zero_bytes_file(self, path):
        """Return True if file <path> is zero bytes in size, else return False"""
        return self._getReturnCodeCmd([self._hadoop_cmd, 'fs', '-test', '-z', self._full_hdfs_path(path)]) == 0

    def ls(self, src, extra_args=[]):
        '''List files in a directory'''
        src = [self._full_hdfs_path(x) for x in src]
        output = self._getStdOutCmd([self._hadoop_cmd, 'fs', '-ls'] + extra_args + src, True)
        return self._transform_ls_output(output, self.hdfs_url)

    def mkdir(self, src, extra_args=[]):
        '''Create a directory'''
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-mkdir'] + extra_args + [self._full_hdfs_path(src)], True)

    def df(self, src):
        '''Perform ``df`` on a path'''
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-df', self._full_hdfs_path(src)], True)

    def du(self, src, extra_args=[]):
        '''Perform ``du`` on a path'''
        src = [self._full_hdfs_path(x) for x in src]
        return self._transform_du_output(self._getStdOutCmd([self._hadoop_cmd, 'fs', '-du'] + extra_args + src, True), self.hdfs_url)

    def count(self, src):
        '''Perform ``count`` on a path'''
        src = [self._full_hdfs_path(x) for x in src]
        return self._transform_count_output(self._getStdOutCmd([self._hadoop_cmd, 'fs', '-count'] + src, True), self.hdfs_url)

    def cat(self, src, extra_args=[], text=False):
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-cat'] + extra_args + [self._full_hdfs_path(src)], text)

    def copyToLocal(self, src, dst, extra_args=[]):
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-copyToLocal'] + extra_args + [self._full_hdfs_path(src), dst], True)

    def getmerge(self, src, dst, extra_args=[]):
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-getmerge'] + extra_args + [self._full_hdfs_path(src), dst], True)

    def tail(self, src, extra_args=[], text=False):
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-tail'] + extra_args + [self._full_hdfs_path(src)], text)

    def text(self, src):
        return self._getStdOutCmd([self._hadoop_cmd, 'fs', '-text', self._full_hdfs_path(src)], True)

    def _getReturnCodeCmd(self, cmd):
        proc = self._getCmdProcess(cmd, True)
        print(proc.communicate())
        return proc.wait()

    def _getCmdProcess(self, cmd, text=False):
        return subprocess.Popen(cmd, stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=text)

    def _getStdOutCmd(self, cmd, text=False):
        return self._getCmdProcess(cmd, text).communicate()[0]

    def _full_hdfs_path(self, src):
        return "%s%s" % (self.hdfs_url, src)

    def _find_mini_cluster_jar(self, path):
        for dirpath, dirnames, filenames in os.walk(path):
            for files in filenames:
                if re.match(".*hadoop-mapreduce-client-jobclient.+-tests.jar", files):
                    return os.path.join(dirpath, files)

    def _start_mini_cluster(self, nnport=None):
        if self._jobclient_jar:
            hadoop_jar = self._jobclient_jar
        else:
            hadoop_jar = self._find_mini_cluster_jar(self._hadoop_home)
        if not hadoop_jar:
            raise Exception("No hadoop jobclient test jar found")
        cmd = [self._hadoop_cmd, 'jar', hadoop_jar,
               'minicluster', '-nomr', '-format']
        if nnport:
            cmd.extend(['-nnport', "%s" % nnport])
        self.hdfs = subprocess.Popen(cmd, bufsize=0, stdout=subprocess.PIPE,
                                     stderr=subprocess.PIPE, universal_newlines=True)

    def _get_namenode_port(self):
        while self.hdfs.poll() is None:
            rlist, wlist, xlist = select.select([self.hdfs.stderr, self.hdfs.stdout], [], [])
            for f in rlist:
                line = f.readline()
                print(line,)
                m = re.match(".*Started MiniDFSCluster -- namenode on port (\d+).*", line)
                if m:
                    return int(m.group(1))

    def _transform_ls_output(self, i, base_path):
        result = []
        for line in i.split("\n"):
            if not line or line.startswith("Found"):
                continue

            (perms, replication, owner, group, length, date, time, path) = re.split("\s+", line)
            node = {}

            if replication == '-':
                replication = 0

            node['permission'] = self._perms_to_int(perms)
            node['block_replication'] = int(replication)
            node['owner'] = owner
            node['group'] = group
            node['length'] = int(length)
            dt = "%s %s" % (date, time)
            node['modification_time'] = long(datetime.datetime.strptime(dt, '%Y-%m-%d %H:%M').strftime('%s'))
            node['path'] = path.replace(base_path, '')
            node['file_type'] = self._get_file_type(perms[0])
            result.append(node)
        return result

    def _transform_du_output(self, i, base_path):
        result = []
        for line in i.split("\n"):
            if line:
                fields = re.split("\s+", line)
                if len(fields) == 3:
                    (length, space_consumed, path) = re.split("\s+", line)
                elif len(fields) == 2:
                    (length, path) = re.split("\s+", line)
                else:
                    raise ValueError("Result of du operation should contain 2"
                                     " or 3 field, but there's %d fields"
                                     % len(fields))
                result.append({"path": path.replace(base_path, ""),
                               "length": long(length)})
        return result

    def _transform_count_output(self, i, base_path):
        result = []
        for line in i.split("\n"):
            if line:
                (_, dir_count, file_count, length, path) = re.split("\s+", line)
                result.append({"path": path.replace(base_path, ""), "length": long(length),
                               "directoryCount": long(dir_count), "fileCount": long(file_count)})
        return result

    def _get_file_type(self, i):
        if i == "-":
            return "f"
        else:
            return i

    def _perms_to_int(self, perms):
        s = ""
        for x in perms[1:]:
            if x == "-":
                s += "0"
            else:
                s += "1"
        octal = "%d%d%d" % (int(s[0:3], 2), int(s[3:6], 2), int(s[6:9], 2))
        return int(octal, 8)



# -*- coding: utf-8 -*-
# Copyright (c) 2013 Spotify AB
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may not
# use this file except in compliance with the License. You may obtain a copy of
# the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations under
# the License.

# python 3 support
from __future__ import absolute_import, print_function, division


class SnakebiteException(Exception):
    """
    Common base class for all snakebite exceptions.
    """
    pass


class FatalException(SnakebiteException):
    """
    FatalException indicates that retry of current operation alone would have the same effect.
    """
    pass


class TransientException(SnakebiteException):
    """
    TransientException indicates that retry of current operation could help.
    """
    pass


class ConnectionFailureException(TransientException):
    def __init__(self, msg):
        super(ConnectionFailureException, self).__init__(msg)


class DirectoryException(FatalException):
    def __init__(self, msg):
        super(DirectoryException, self).__init__(msg)


class FileAlreadyExistsException(FatalException):
    def __init__(self, msg):
        super(FileAlreadyExistsException, self).__init__(msg)


class FileException(FatalException):
    def __init__(self, msg):
        super(FileException, self).__init__(msg)


class FileNotFoundException(FatalException):
    def __init__(self, msg):
        super(FileNotFoundException, self).__init__(msg)


class InvalidInputException(FatalException):
    def __init__(self, msg):
        super(InvalidInputException, self).__init__(msg)


class OutOfNNException(TransientException):
    def __init__(self, msg):
        super(OutOfNNException, self).__init__(msg)


class RequestError(TransientException):
    """
    Note: request error could be transient and could be fatal, depending on underlying error.
    """
    def __init__(self, msg):
        super(RequestError, self).__init__(msg)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: hdfs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import Security_pb2 as Security__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='hdfs.proto',
  package='hadoop.hdfs',
  syntax='proto2',
  serialized_pb=_b('\n\nhdfs.proto\x12\x0bhadoop.hdfs\x1a\x0eSecurity.proto\"c\n\x12\x45xtendedBlockProto\x12\x0e\n\x06poolId\x18\x01 \x02(\t\x12\x0f\n\x07\x62lockId\x18\x02 \x02(\x04\x12\x17\n\x0fgenerationStamp\x18\x03 \x02(\x04\x12\x13\n\x08numBytes\x18\x04 \x01(\x04:\x01\x30\"\x96\x01\n\x0f\x44\x61tanodeIDProto\x12\x0e\n\x06ipAddr\x18\x01 \x02(\t\x12\x10\n\x08hostName\x18\x02 \x02(\t\x12\x11\n\tstorageID\x18\x03 \x02(\t\x12\x10\n\x08xferPort\x18\x04 \x02(\r\x12\x10\n\x08infoPort\x18\x05 \x02(\r\x12\x0f\n\x07ipcPort\x18\x06 \x02(\r\x12\x19\n\x0einfoSecurePort\x18\x07 \x01(\r:\x01\x30\"G\n\x12\x44\x61tanodeInfosProto\x12\x31\n\tdatanodes\x18\x01 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\"\xea\x02\n\x11\x44\x61tanodeInfoProto\x12(\n\x02id\x18\x01 \x02(\x0b\x32\x1c.hadoop.hdfs.DatanodeIDProto\x12\x13\n\x08\x63\x61pacity\x18\x02 \x01(\x04:\x01\x30\x12\x12\n\x07\x64\x66sUsed\x18\x03 \x01(\x04:\x01\x30\x12\x14\n\tremaining\x18\x04 \x01(\x04:\x01\x30\x12\x18\n\rblockPoolUsed\x18\x05 \x01(\x04:\x01\x30\x12\x15\n\nlastUpdate\x18\x06 \x01(\x04:\x01\x30\x12\x17\n\x0cxceiverCount\x18\x07 \x01(\r:\x01\x30\x12\x10\n\x08location\x18\x08 \x01(\t\x12\x45\n\nadminState\x18\n \x01(\x0e\x32).hadoop.hdfs.DatanodeInfoProto.AdminState:\x06NORMAL\"I\n\nAdminState\x12\n\n\x06NORMAL\x10\x00\x12\x1b\n\x17\x44\x45\x43OMMISSION_INPROGRESS\x10\x01\x12\x12\n\x0e\x44\x45\x43OMMISSIONED\x10\x02\"\x8a\x01\n\x13\x43ontentSummaryProto\x12\x0e\n\x06length\x18\x01 \x02(\x04\x12\x11\n\tfileCount\x18\x02 \x02(\x04\x12\x16\n\x0e\x64irectoryCount\x18\x03 \x02(\x04\x12\r\n\x05quota\x18\x04 \x02(\x04\x12\x15\n\rspaceConsumed\x18\x05 \x02(\x04\x12\x12\n\nspaceQuota\x18\x06 \x02(\x04\"7\n\x16\x43orruptFileBlocksProto\x12\r\n\x05\x66iles\x18\x01 \x03(\t\x12\x0e\n\x06\x63ookie\x18\x02 \x02(\t\"!\n\x11\x46sPermissionProto\x12\x0c\n\x04perm\x18\x01 \x02(\r\"\xbd\x01\n\x11LocatedBlockProto\x12*\n\x01\x62\x18\x01 \x02(\x0b\x32\x1f.hadoop.hdfs.ExtendedBlockProto\x12\x0e\n\x06offset\x18\x02 \x02(\x04\x12,\n\x04locs\x18\x03 \x03(\x0b\x32\x1e.hadoop.hdfs.DatanodeInfoProto\x12\x0f\n\x07\x63orrupt\x18\x04 \x02(\x08\x12-\n\nblockToken\x18\x05 \x02(\x0b\x32\x19.hadoop.common.TokenProto\"\x93\x01\n\x16\x44\x61taEncryptionKeyProto\x12\r\n\x05keyId\x18\x01 \x02(\r\x12\x13\n\x0b\x62lockPoolId\x18\x02 \x02(\t\x12\r\n\x05nonce\x18\x03 \x02(\x0c\x12\x15\n\rencryptionKey\x18\x04 \x02(\x0c\x12\x12\n\nexpiryDate\x18\x05 \x02(\x04\x12\x1b\n\x13\x65ncryptionAlgorithm\x18\x06 \x01(\t\"\xc3\x01\n\x12LocatedBlocksProto\x12\x12\n\nfileLength\x18\x01 \x02(\x04\x12.\n\x06\x62locks\x18\x02 \x03(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\x12\x19\n\x11underConstruction\x18\x03 \x02(\x08\x12\x31\n\tlastBlock\x18\x04 \x01(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\x12\x1b\n\x13isLastBlockComplete\x18\x05 \x02(\x08\"\xcc\x03\n\x13HdfsFileStatusProto\x12;\n\x08\x66ileType\x18\x01 \x02(\x0e\x32).hadoop.hdfs.HdfsFileStatusProto.FileType\x12\x0c\n\x04path\x18\x02 \x02(\x0c\x12\x0e\n\x06length\x18\x03 \x02(\x04\x12\x32\n\npermission\x18\x04 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\x12\r\n\x05owner\x18\x05 \x02(\t\x12\r\n\x05group\x18\x06 \x02(\t\x12\x19\n\x11modification_time\x18\x07 \x02(\x04\x12\x13\n\x0b\x61\x63\x63\x65ss_time\x18\x08 \x02(\x04\x12\x0f\n\x07symlink\x18\t \x01(\x0c\x12\x1c\n\x11\x62lock_replication\x18\n \x01(\r:\x01\x30\x12\x14\n\tblocksize\x18\x0b \x01(\x04:\x01\x30\x12\x32\n\tlocations\x18\x0c \x01(\x0b\x32\x1f.hadoop.hdfs.LocatedBlocksProto\x12\x11\n\x06\x66ileId\x18\r \x01(\x04:\x01\x30\x12\x17\n\x0b\x63hildrenNum\x18\x0e \x01(\x05:\x02-1\"3\n\x08\x46ileType\x12\n\n\x06IS_DIR\x10\x01\x12\x0b\n\x07IS_FILE\x10\x02\x12\x0e\n\nIS_SYMLINK\x10\x03\"\x8e\x02\n\x15\x46sServerDefaultsProto\x12\x11\n\tblockSize\x18\x01 \x02(\x04\x12\x18\n\x10\x62ytesPerChecksum\x18\x02 \x02(\r\x12\x17\n\x0fwritePacketSize\x18\x03 \x02(\r\x12\x13\n\x0breplication\x18\x04 \x02(\r\x12\x16\n\x0e\x66ileBufferSize\x18\x05 \x02(\r\x12\"\n\x13\x65ncryptDataTransfer\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x18\n\rtrashInterval\x18\x07 \x01(\x04:\x01\x30\x12\x44\n\x0c\x63hecksumType\x18\x08 \x01(\x0e\x32\x1e.hadoop.hdfs.ChecksumTypeProto:\x0e\x43HECKSUM_CRC32\"k\n\x15\x44irectoryListingProto\x12\x38\n\x0epartialListing\x18\x01 \x03(\x0b\x32 .hadoop.hdfs.HdfsFileStatusProto\x12\x18\n\x10remainingEntries\x18\x02 \x02(\r\"\xa2\x01\n!SnapshottableDirectoryStatusProto\x12\x33\n\tdirStatus\x18\x01 \x02(\x0b\x32 .hadoop.hdfs.HdfsFileStatusProto\x12\x16\n\x0esnapshot_quota\x18\x02 \x02(\r\x12\x17\n\x0fsnapshot_number\x18\x03 \x02(\r\x12\x17\n\x0fparent_fullpath\x18\x04 \x02(\x0c\"u\n\"SnapshottableDirectoryListingProto\x12O\n\x17snapshottableDirListing\x18\x01 \x03(\x0b\x32..hadoop.hdfs.SnapshottableDirectoryStatusProto\"K\n\x1cSnapshotDiffReportEntryProto\x12\x10\n\x08\x66ullpath\x18\x01 \x02(\x0c\x12\x19\n\x11modificationLabel\x18\x02 \x02(\t\"\x9f\x01\n\x17SnapshotDiffReportProto\x12\x14\n\x0csnapshotRoot\x18\x01 \x02(\t\x12\x14\n\x0c\x66romSnapshot\x18\x02 \x02(\t\x12\x12\n\ntoSnapshot\x18\x03 \x02(\t\x12\x44\n\x11\x64iffReportEntries\x18\x04 \x03(\x0b\x32).hadoop.hdfs.SnapshotDiffReportEntryProto\"_\n\x10StorageInfoProto\x12\x15\n\rlayoutVersion\x18\x01 \x02(\r\x12\x12\n\nnamespceID\x18\x02 \x02(\r\x12\x11\n\tclusterID\x18\x03 \x02(\t\x12\r\n\x05\x63Time\x18\x04 \x02(\x04\"\x89\x02\n\x19NamenodeRegistrationProto\x12\x12\n\nrpcAddress\x18\x01 \x02(\t\x12\x13\n\x0bhttpAddress\x18\x02 \x02(\t\x12\x32\n\x0bstorageInfo\x18\x03 \x02(\x0b\x32\x1d.hadoop.hdfs.StorageInfoProto\x12P\n\x04role\x18\x04 \x01(\x0e\x32\x38.hadoop.hdfs.NamenodeRegistrationProto.NamenodeRoleProto:\x08NAMENODE\"=\n\x11NamenodeRoleProto\x12\x0c\n\x08NAMENODE\x10\x01\x12\n\n\x06\x42\x41\x43KUP\x10\x02\x12\x0e\n\nCHECKPOINT\x10\x03\"\x9d\x01\n\x18\x43heckpointSignatureProto\x12\x13\n\x0b\x62lockPoolId\x18\x01 \x02(\t\x12 \n\x18mostRecentCheckpointTxId\x18\x02 \x02(\x04\x12\x16\n\x0e\x63urSegmentTxId\x18\x03 \x02(\x04\x12\x32\n\x0bstorageInfo\x18\x04 \x02(\x0b\x32\x1d.hadoop.hdfs.StorageInfoProto\"\xcc\x01\n\x14NamenodeCommandProto\x12\x0e\n\x06\x61\x63tion\x18\x01 \x02(\r\x12\x34\n\x04type\x18\x02 \x02(\x0e\x32&.hadoop.hdfs.NamenodeCommandProto.Type\x12:\n\rcheckpointCmd\x18\x03 \x01(\x0b\x32#.hadoop.hdfs.CheckpointCommandProto\"2\n\x04Type\x12\x13\n\x0fNamenodeCommand\x10\x00\x12\x15\n\x11\x43heckPointCommand\x10\x01\"m\n\x16\x43heckpointCommandProto\x12\x38\n\tsignature\x18\x01 \x02(\x0b\x32%.hadoop.hdfs.CheckpointSignatureProto\x12\x19\n\x11needToReturnImage\x18\x02 \x02(\x08\"D\n\nBlockProto\x12\x0f\n\x07\x62lockId\x18\x01 \x02(\x04\x12\x10\n\x08genStamp\x18\x02 \x02(\x04\x12\x13\n\x08numBytes\x18\x03 \x01(\x04:\x01\x30\"U\n\x17\x42lockWithLocationsProto\x12&\n\x05\x62lock\x18\x01 \x02(\x0b\x32\x17.hadoop.hdfs.BlockProto\x12\x12\n\nstorageIDs\x18\x02 \x03(\t\"P\n\x18\x42locksWithLocationsProto\x12\x34\n\x06\x62locks\x18\x01 \x03(\x0b\x32$.hadoop.hdfs.BlockWithLocationsProto\"U\n\x12RemoteEditLogProto\x12\x11\n\tstartTxId\x18\x01 \x02(\x04\x12\x0f\n\x07\x65ndTxId\x18\x02 \x02(\x04\x12\x1b\n\x0cisInProgress\x18\x03 \x01(\x08:\x05\x66\x61lse\"K\n\x1aRemoteEditLogManifestProto\x12-\n\x04logs\x18\x01 \x03(\x0b\x32\x1f.hadoop.hdfs.RemoteEditLogProto\"\x9c\x01\n\x12NamespaceInfoProto\x12\x14\n\x0c\x62uildVersion\x18\x01 \x02(\t\x12\x0e\n\x06unused\x18\x02 \x02(\r\x12\x13\n\x0b\x62lockPoolID\x18\x03 \x02(\t\x12\x32\n\x0bstorageInfo\x18\x04 \x02(\x0b\x32\x1d.hadoop.hdfs.StorageInfoProto\x12\x17\n\x0fsoftwareVersion\x18\x05 \x02(\t\"D\n\rBlockKeyProto\x12\r\n\x05keyId\x18\x01 \x02(\r\x12\x12\n\nexpiryDate\x18\x02 \x02(\x04\x12\x10\n\x08keyBytes\x18\x03 \x01(\x0c\"\xc4\x01\n\x16\x45xportedBlockKeysProto\x12\x1b\n\x13isBlockTokenEnabled\x18\x01 \x02(\x08\x12\x19\n\x11keyUpdateInterval\x18\x02 \x02(\x04\x12\x15\n\rtokenLifeTime\x18\x03 \x02(\x04\x12.\n\ncurrentKey\x18\x04 \x02(\x0b\x32\x1a.hadoop.hdfs.BlockKeyProto\x12+\n\x07\x61llKeys\x18\x05 \x03(\x0b\x32\x1a.hadoop.hdfs.BlockKeyProto\"Z\n\x14RecoveringBlockProto\x12\x13\n\x0bnewGenStamp\x18\x01 \x02(\x04\x12-\n\x05\x62lock\x18\x02 \x02(\x0b\x32\x1e.hadoop.hdfs.LocatedBlockProto\"\x15\n\x13VersionRequestProto\"E\n\x14VersionResponseProto\x12-\n\x04info\x18\x01 \x02(\x0b\x32\x1f.hadoop.hdfs.NamespaceInfoProto\"\xa5\x01\n\x11SnapshotInfoProto\x12\x14\n\x0csnapshotName\x18\x01 \x02(\t\x12\x14\n\x0csnapshotRoot\x18\x02 \x02(\t\x12\x32\n\npermission\x18\x03 \x02(\x0b\x32\x1e.hadoop.hdfs.FsPermissionProto\x12\r\n\x05owner\x18\x04 \x02(\t\x12\r\n\x05group\x18\x05 \x02(\t\x12\x12\n\ncreateTime\x18\x06 \x02(\t*O\n\x11\x43hecksumTypeProto\x12\x11\n\rCHECKSUM_NULL\x10\x00\x12\x12\n\x0e\x43HECKSUM_CRC32\x10\x01\x12\x13\n\x0f\x43HECKSUM_CRC32C\x10\x02*L\n\x11ReplicaStateProto\x12\r\n\tFINALIZED\x10\x00\x12\x07\n\x03RBW\x10\x01\x12\x07\n\x03RWR\x10\x02\x12\x07\n\x03RUR\x10\x03\x12\r\n\tTEMPORARY\x10\x04\x42\x36\n%org.apache.hadoop.hdfs.protocol.protoB\nHdfsProtos\xa0\x01\x01')
  ,
  dependencies=[Security__pb2.DESCRIPTOR,])
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

_CHECKSUMTYPEPROTO = _descriptor.EnumDescriptor(
  name='ChecksumTypeProto',
  full_name='hadoop.hdfs.ChecksumTypeProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='CHECKSUM_NULL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKSUM_CRC32', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKSUM_CRC32C', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4904,
  serialized_end=4983,
)
_sym_db.RegisterEnumDescriptor(_CHECKSUMTYPEPROTO)

ChecksumTypeProto = enum_type_wrapper.EnumTypeWrapper(_CHECKSUMTYPEPROTO)
_REPLICASTATEPROTO = _descriptor.EnumDescriptor(
  name='ReplicaStateProto',
  full_name='hadoop.hdfs.ReplicaStateProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FINALIZED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RBW', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RWR', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUR', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMPORARY', index=4, number=4,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4985,
  serialized_end=5061,
)
_sym_db.RegisterEnumDescriptor(_REPLICASTATEPROTO)

ReplicaStateProto = enum_type_wrapper.EnumTypeWrapper(_REPLICASTATEPROTO)
CHECKSUM_NULL = 0
CHECKSUM_CRC32 = 1
CHECKSUM_CRC32C = 2
FINALIZED = 0
RBW = 1
RWR = 2
RUR = 3
TEMPORARY = 4


_DATANODEINFOPROTO_ADMINSTATE = _descriptor.EnumDescriptor(
  name='AdminState',
  full_name='hadoop.hdfs.DatanodeInfoProto.AdminState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECOMMISSION_INPROGRESS', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECOMMISSIONED', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=660,
  serialized_end=733,
)
_sym_db.RegisterEnumDescriptor(_DATANODEINFOPROTO_ADMINSTATE)

_HDFSFILESTATUSPROTO_FILETYPE = _descriptor.EnumDescriptor(
  name='FileType',
  full_name='hadoop.hdfs.HdfsFileStatusProto.FileType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='IS_DIR', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_FILE', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='IS_SYMLINK', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1918,
  serialized_end=1969,
)
_sym_db.RegisterEnumDescriptor(_HDFSFILESTATUSPROTO_FILETYPE)

_NAMENODEREGISTRATIONPROTO_NAMENODEROLEPROTO = _descriptor.EnumDescriptor(
  name='NamenodeRoleProto',
  full_name='hadoop.hdfs.NamenodeRegistrationProto.NamenodeRoleProto',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NAMENODE', index=0, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BACKUP', index=1, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHECKPOINT', index=2, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3178,
  serialized_end=3239,
)
_sym_db.RegisterEnumDescriptor(_NAMENODEREGISTRATIONPROTO_NAMENODEROLEPROTO)

_NAMENODECOMMANDPROTO_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='hadoop.hdfs.NamenodeCommandProto.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='NamenodeCommand', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CheckPointCommand', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=3556,
  serialized_end=3606,
)
_sym_db.RegisterEnumDescriptor(_NAMENODECOMMANDPROTO_TYPE)


_EXTENDEDBLOCKPROTO = _descriptor.Descriptor(
  name='ExtendedBlockProto',
  full_name='hadoop.hdfs.ExtendedBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='poolId', full_name='hadoop.hdfs.ExtendedBlockProto.poolId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockId', full_name='hadoop.hdfs.ExtendedBlockProto.blockId', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='generationStamp', full_name='hadoop.hdfs.ExtendedBlockProto.generationStamp', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numBytes', full_name='hadoop.hdfs.ExtendedBlockProto.numBytes', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=43,
  serialized_end=142,
)


_DATANODEIDPROTO = _descriptor.Descriptor(
  name='DatanodeIDProto',
  full_name='hadoop.hdfs.DatanodeIDProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ipAddr', full_name='hadoop.hdfs.DatanodeIDProto.ipAddr', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='hostName', full_name='hadoop.hdfs.DatanodeIDProto.hostName', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='storageID', full_name='hadoop.hdfs.DatanodeIDProto.storageID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xferPort', full_name='hadoop.hdfs.DatanodeIDProto.xferPort', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='infoPort', full_name='hadoop.hdfs.DatanodeIDProto.infoPort', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ipcPort', full_name='hadoop.hdfs.DatanodeIDProto.ipcPort', index=5,
      number=6, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='infoSecurePort', full_name='hadoop.hdfs.DatanodeIDProto.infoSecurePort', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=145,
  serialized_end=295,
)


_DATANODEINFOSPROTO = _descriptor.Descriptor(
  name='DatanodeInfosProto',
  full_name='hadoop.hdfs.DatanodeInfosProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='datanodes', full_name='hadoop.hdfs.DatanodeInfosProto.datanodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=297,
  serialized_end=368,
)


_DATANODEINFOPROTO = _descriptor.Descriptor(
  name='DatanodeInfoProto',
  full_name='hadoop.hdfs.DatanodeInfoProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='hadoop.hdfs.DatanodeInfoProto.id', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='capacity', full_name='hadoop.hdfs.DatanodeInfoProto.capacity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dfsUsed', full_name='hadoop.hdfs.DatanodeInfoProto.dfsUsed', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remaining', full_name='hadoop.hdfs.DatanodeInfoProto.remaining', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockPoolUsed', full_name='hadoop.hdfs.DatanodeInfoProto.blockPoolUsed', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastUpdate', full_name='hadoop.hdfs.DatanodeInfoProto.lastUpdate', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='xceiverCount', full_name='hadoop.hdfs.DatanodeInfoProto.xceiverCount', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='location', full_name='hadoop.hdfs.DatanodeInfoProto.location', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='adminState', full_name='hadoop.hdfs.DatanodeInfoProto.adminState', index=8,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATANODEINFOPROTO_ADMINSTATE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=733,
)


_CONTENTSUMMARYPROTO = _descriptor.Descriptor(
  name='ContentSummaryProto',
  full_name='hadoop.hdfs.ContentSummaryProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='hadoop.hdfs.ContentSummaryProto.length', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileCount', full_name='hadoop.hdfs.ContentSummaryProto.fileCount', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='directoryCount', full_name='hadoop.hdfs.ContentSummaryProto.directoryCount', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='quota', full_name='hadoop.hdfs.ContentSummaryProto.quota', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spaceConsumed', full_name='hadoop.hdfs.ContentSummaryProto.spaceConsumed', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='spaceQuota', full_name='hadoop.hdfs.ContentSummaryProto.spaceQuota', index=5,
      number=6, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=736,
  serialized_end=874,
)


_CORRUPTFILEBLOCKSPROTO = _descriptor.Descriptor(
  name='CorruptFileBlocksProto',
  full_name='hadoop.hdfs.CorruptFileBlocksProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='files', full_name='hadoop.hdfs.CorruptFileBlocksProto.files', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cookie', full_name='hadoop.hdfs.CorruptFileBlocksProto.cookie', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=876,
  serialized_end=931,
)


_FSPERMISSIONPROTO = _descriptor.Descriptor(
  name='FsPermissionProto',
  full_name='hadoop.hdfs.FsPermissionProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='perm', full_name='hadoop.hdfs.FsPermissionProto.perm', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=933,
  serialized_end=966,
)


_LOCATEDBLOCKPROTO = _descriptor.Descriptor(
  name='LocatedBlockProto',
  full_name='hadoop.hdfs.LocatedBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='b', full_name='hadoop.hdfs.LocatedBlockProto.b', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='offset', full_name='hadoop.hdfs.LocatedBlockProto.offset', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='locs', full_name='hadoop.hdfs.LocatedBlockProto.locs', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='corrupt', full_name='hadoop.hdfs.LocatedBlockProto.corrupt', index=3,
      number=4, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockToken', full_name='hadoop.hdfs.LocatedBlockProto.blockToken', index=4,
      number=5, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=969,
  serialized_end=1158,
)


_DATAENCRYPTIONKEYPROTO = _descriptor.Descriptor(
  name='DataEncryptionKeyProto',
  full_name='hadoop.hdfs.DataEncryptionKeyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyId', full_name='hadoop.hdfs.DataEncryptionKeyProto.keyId', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockPoolId', full_name='hadoop.hdfs.DataEncryptionKeyProto.blockPoolId', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='nonce', full_name='hadoop.hdfs.DataEncryptionKeyProto.nonce', index=2,
      number=3, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encryptionKey', full_name='hadoop.hdfs.DataEncryptionKeyProto.encryptionKey', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiryDate', full_name='hadoop.hdfs.DataEncryptionKeyProto.expiryDate', index=4,
      number=5, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encryptionAlgorithm', full_name='hadoop.hdfs.DataEncryptionKeyProto.encryptionAlgorithm', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1161,
  serialized_end=1308,
)


_LOCATEDBLOCKSPROTO = _descriptor.Descriptor(
  name='LocatedBlocksProto',
  full_name='hadoop.hdfs.LocatedBlocksProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileLength', full_name='hadoop.hdfs.LocatedBlocksProto.fileLength', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blocks', full_name='hadoop.hdfs.LocatedBlocksProto.blocks', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='underConstruction', full_name='hadoop.hdfs.LocatedBlocksProto.underConstruction', index=2,
      number=3, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lastBlock', full_name='hadoop.hdfs.LocatedBlocksProto.lastBlock', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isLastBlockComplete', full_name='hadoop.hdfs.LocatedBlocksProto.isLastBlockComplete', index=4,
      number=5, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1311,
  serialized_end=1506,
)


_HDFSFILESTATUSPROTO = _descriptor.Descriptor(
  name='HdfsFileStatusProto',
  full_name='hadoop.hdfs.HdfsFileStatusProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fileType', full_name='hadoop.hdfs.HdfsFileStatusProto.fileType', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='path', full_name='hadoop.hdfs.HdfsFileStatusProto.path', index=1,
      number=2, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='length', full_name='hadoop.hdfs.HdfsFileStatusProto.length', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='hadoop.hdfs.HdfsFileStatusProto.permission', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='hadoop.hdfs.HdfsFileStatusProto.owner', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group', full_name='hadoop.hdfs.HdfsFileStatusProto.group', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modification_time', full_name='hadoop.hdfs.HdfsFileStatusProto.modification_time', index=6,
      number=7, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='access_time', full_name='hadoop.hdfs.HdfsFileStatusProto.access_time', index=7,
      number=8, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='symlink', full_name='hadoop.hdfs.HdfsFileStatusProto.symlink', index=8,
      number=9, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='block_replication', full_name='hadoop.hdfs.HdfsFileStatusProto.block_replication', index=9,
      number=10, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blocksize', full_name='hadoop.hdfs.HdfsFileStatusProto.blocksize', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='locations', full_name='hadoop.hdfs.HdfsFileStatusProto.locations', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileId', full_name='hadoop.hdfs.HdfsFileStatusProto.fileId', index=12,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='childrenNum', full_name='hadoop.hdfs.HdfsFileStatusProto.childrenNum', index=13,
      number=14, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=-1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _HDFSFILESTATUSPROTO_FILETYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1509,
  serialized_end=1969,
)


_FSSERVERDEFAULTSPROTO = _descriptor.Descriptor(
  name='FsServerDefaultsProto',
  full_name='hadoop.hdfs.FsServerDefaultsProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockSize', full_name='hadoop.hdfs.FsServerDefaultsProto.blockSize', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='bytesPerChecksum', full_name='hadoop.hdfs.FsServerDefaultsProto.bytesPerChecksum', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='writePacketSize', full_name='hadoop.hdfs.FsServerDefaultsProto.writePacketSize', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='replication', full_name='hadoop.hdfs.FsServerDefaultsProto.replication', index=3,
      number=4, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fileBufferSize', full_name='hadoop.hdfs.FsServerDefaultsProto.fileBufferSize', index=4,
      number=5, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='encryptDataTransfer', full_name='hadoop.hdfs.FsServerDefaultsProto.encryptDataTransfer', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='trashInterval', full_name='hadoop.hdfs.FsServerDefaultsProto.trashInterval', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='checksumType', full_name='hadoop.hdfs.FsServerDefaultsProto.checksumType', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1972,
  serialized_end=2242,
)


_DIRECTORYLISTINGPROTO = _descriptor.Descriptor(
  name='DirectoryListingProto',
  full_name='hadoop.hdfs.DirectoryListingProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='partialListing', full_name='hadoop.hdfs.DirectoryListingProto.partialListing', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='remainingEntries', full_name='hadoop.hdfs.DirectoryListingProto.remainingEntries', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2244,
  serialized_end=2351,
)


_SNAPSHOTTABLEDIRECTORYSTATUSPROTO = _descriptor.Descriptor(
  name='SnapshottableDirectoryStatusProto',
  full_name='hadoop.hdfs.SnapshottableDirectoryStatusProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dirStatus', full_name='hadoop.hdfs.SnapshottableDirectoryStatusProto.dirStatus', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshot_quota', full_name='hadoop.hdfs.SnapshottableDirectoryStatusProto.snapshot_quota', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshot_number', full_name='hadoop.hdfs.SnapshottableDirectoryStatusProto.snapshot_number', index=2,
      number=3, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parent_fullpath', full_name='hadoop.hdfs.SnapshottableDirectoryStatusProto.parent_fullpath', index=3,
      number=4, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2354,
  serialized_end=2516,
)


_SNAPSHOTTABLEDIRECTORYLISTINGPROTO = _descriptor.Descriptor(
  name='SnapshottableDirectoryListingProto',
  full_name='hadoop.hdfs.SnapshottableDirectoryListingProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshottableDirListing', full_name='hadoop.hdfs.SnapshottableDirectoryListingProto.snapshottableDirListing', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2518,
  serialized_end=2635,
)


_SNAPSHOTDIFFREPORTENTRYPROTO = _descriptor.Descriptor(
  name='SnapshotDiffReportEntryProto',
  full_name='hadoop.hdfs.SnapshotDiffReportEntryProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fullpath', full_name='hadoop.hdfs.SnapshotDiffReportEntryProto.fullpath', index=0,
      number=1, type=12, cpp_type=9, label=2,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='modificationLabel', full_name='hadoop.hdfs.SnapshotDiffReportEntryProto.modificationLabel', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2637,
  serialized_end=2712,
)


_SNAPSHOTDIFFREPORTPROTO = _descriptor.Descriptor(
  name='SnapshotDiffReportProto',
  full_name='hadoop.hdfs.SnapshotDiffReportProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.SnapshotDiffReportProto.snapshotRoot', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='fromSnapshot', full_name='hadoop.hdfs.SnapshotDiffReportProto.fromSnapshot', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='toSnapshot', full_name='hadoop.hdfs.SnapshotDiffReportProto.toSnapshot', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='diffReportEntries', full_name='hadoop.hdfs.SnapshotDiffReportProto.diffReportEntries', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2715,
  serialized_end=2874,
)


_STORAGEINFOPROTO = _descriptor.Descriptor(
  name='StorageInfoProto',
  full_name='hadoop.hdfs.StorageInfoProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='layoutVersion', full_name='hadoop.hdfs.StorageInfoProto.layoutVersion', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespceID', full_name='hadoop.hdfs.StorageInfoProto.namespceID', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='clusterID', full_name='hadoop.hdfs.StorageInfoProto.clusterID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='cTime', full_name='hadoop.hdfs.StorageInfoProto.cTime', index=3,
      number=4, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2876,
  serialized_end=2971,
)


_NAMENODEREGISTRATIONPROTO = _descriptor.Descriptor(
  name='NamenodeRegistrationProto',
  full_name='hadoop.hdfs.NamenodeRegistrationProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='rpcAddress', full_name='hadoop.hdfs.NamenodeRegistrationProto.rpcAddress', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='httpAddress', full_name='hadoop.hdfs.NamenodeRegistrationProto.httpAddress', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='storageInfo', full_name='hadoop.hdfs.NamenodeRegistrationProto.storageInfo', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='hadoop.hdfs.NamenodeRegistrationProto.role', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NAMENODEREGISTRATIONPROTO_NAMENODEROLEPROTO,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2974,
  serialized_end=3239,
)


_CHECKPOINTSIGNATUREPROTO = _descriptor.Descriptor(
  name='CheckpointSignatureProto',
  full_name='hadoop.hdfs.CheckpointSignatureProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockPoolId', full_name='hadoop.hdfs.CheckpointSignatureProto.blockPoolId', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='mostRecentCheckpointTxId', full_name='hadoop.hdfs.CheckpointSignatureProto.mostRecentCheckpointTxId', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='curSegmentTxId', full_name='hadoop.hdfs.CheckpointSignatureProto.curSegmentTxId', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='storageInfo', full_name='hadoop.hdfs.CheckpointSignatureProto.storageInfo', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3242,
  serialized_end=3399,
)


_NAMENODECOMMANDPROTO = _descriptor.Descriptor(
  name='NamenodeCommandProto',
  full_name='hadoop.hdfs.NamenodeCommandProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='action', full_name='hadoop.hdfs.NamenodeCommandProto.action', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='hadoop.hdfs.NamenodeCommandProto.type', index=1,
      number=2, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='checkpointCmd', full_name='hadoop.hdfs.NamenodeCommandProto.checkpointCmd', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NAMENODECOMMANDPROTO_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3402,
  serialized_end=3606,
)


_CHECKPOINTCOMMANDPROTO = _descriptor.Descriptor(
  name='CheckpointCommandProto',
  full_name='hadoop.hdfs.CheckpointCommandProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='signature', full_name='hadoop.hdfs.CheckpointCommandProto.signature', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='needToReturnImage', full_name='hadoop.hdfs.CheckpointCommandProto.needToReturnImage', index=1,
      number=2, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3608,
  serialized_end=3717,
)


_BLOCKPROTO = _descriptor.Descriptor(
  name='BlockProto',
  full_name='hadoop.hdfs.BlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blockId', full_name='hadoop.hdfs.BlockProto.blockId', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='genStamp', full_name='hadoop.hdfs.BlockProto.genStamp', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='numBytes', full_name='hadoop.hdfs.BlockProto.numBytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3719,
  serialized_end=3787,
)


_BLOCKWITHLOCATIONSPROTO = _descriptor.Descriptor(
  name='BlockWithLocationsProto',
  full_name='hadoop.hdfs.BlockWithLocationsProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.BlockWithLocationsProto.block', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='storageIDs', full_name='hadoop.hdfs.BlockWithLocationsProto.storageIDs', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3789,
  serialized_end=3874,
)


_BLOCKSWITHLOCATIONSPROTO = _descriptor.Descriptor(
  name='BlocksWithLocationsProto',
  full_name='hadoop.hdfs.BlocksWithLocationsProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='blocks', full_name='hadoop.hdfs.BlocksWithLocationsProto.blocks', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3876,
  serialized_end=3956,
)


_REMOTEEDITLOGPROTO = _descriptor.Descriptor(
  name='RemoteEditLogProto',
  full_name='hadoop.hdfs.RemoteEditLogProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='startTxId', full_name='hadoop.hdfs.RemoteEditLogProto.startTxId', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='endTxId', full_name='hadoop.hdfs.RemoteEditLogProto.endTxId', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='isInProgress', full_name='hadoop.hdfs.RemoteEditLogProto.isInProgress', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3958,
  serialized_end=4043,
)


_REMOTEEDITLOGMANIFESTPROTO = _descriptor.Descriptor(
  name='RemoteEditLogManifestProto',
  full_name='hadoop.hdfs.RemoteEditLogManifestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='logs', full_name='hadoop.hdfs.RemoteEditLogManifestProto.logs', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4045,
  serialized_end=4120,
)


_NAMESPACEINFOPROTO = _descriptor.Descriptor(
  name='NamespaceInfoProto',
  full_name='hadoop.hdfs.NamespaceInfoProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='buildVersion', full_name='hadoop.hdfs.NamespaceInfoProto.buildVersion', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='unused', full_name='hadoop.hdfs.NamespaceInfoProto.unused', index=1,
      number=2, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='blockPoolID', full_name='hadoop.hdfs.NamespaceInfoProto.blockPoolID', index=2,
      number=3, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='storageInfo', full_name='hadoop.hdfs.NamespaceInfoProto.storageInfo', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='softwareVersion', full_name='hadoop.hdfs.NamespaceInfoProto.softwareVersion', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4123,
  serialized_end=4279,
)


_BLOCKKEYPROTO = _descriptor.Descriptor(
  name='BlockKeyProto',
  full_name='hadoop.hdfs.BlockKeyProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='keyId', full_name='hadoop.hdfs.BlockKeyProto.keyId', index=0,
      number=1, type=13, cpp_type=3, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='expiryDate', full_name='hadoop.hdfs.BlockKeyProto.expiryDate', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyBytes', full_name='hadoop.hdfs.BlockKeyProto.keyBytes', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4281,
  serialized_end=4349,
)


_EXPORTEDBLOCKKEYSPROTO = _descriptor.Descriptor(
  name='ExportedBlockKeysProto',
  full_name='hadoop.hdfs.ExportedBlockKeysProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='isBlockTokenEnabled', full_name='hadoop.hdfs.ExportedBlockKeysProto.isBlockTokenEnabled', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='keyUpdateInterval', full_name='hadoop.hdfs.ExportedBlockKeysProto.keyUpdateInterval', index=1,
      number=2, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tokenLifeTime', full_name='hadoop.hdfs.ExportedBlockKeysProto.tokenLifeTime', index=2,
      number=3, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='currentKey', full_name='hadoop.hdfs.ExportedBlockKeysProto.currentKey', index=3,
      number=4, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='allKeys', full_name='hadoop.hdfs.ExportedBlockKeysProto.allKeys', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4352,
  serialized_end=4548,
)


_RECOVERINGBLOCKPROTO = _descriptor.Descriptor(
  name='RecoveringBlockProto',
  full_name='hadoop.hdfs.RecoveringBlockProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='newGenStamp', full_name='hadoop.hdfs.RecoveringBlockProto.newGenStamp', index=0,
      number=1, type=4, cpp_type=4, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='block', full_name='hadoop.hdfs.RecoveringBlockProto.block', index=1,
      number=2, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4550,
  serialized_end=4640,
)


_VERSIONREQUESTPROTO = _descriptor.Descriptor(
  name='VersionRequestProto',
  full_name='hadoop.hdfs.VersionRequestProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4642,
  serialized_end=4663,
)


_VERSIONRESPONSEPROTO = _descriptor.Descriptor(
  name='VersionResponseProto',
  full_name='hadoop.hdfs.VersionResponseProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='info', full_name='hadoop.hdfs.VersionResponseProto.info', index=0,
      number=1, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4665,
  serialized_end=4734,
)


_SNAPSHOTINFOPROTO = _descriptor.Descriptor(
  name='SnapshotInfoProto',
  full_name='hadoop.hdfs.SnapshotInfoProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='snapshotName', full_name='hadoop.hdfs.SnapshotInfoProto.snapshotName', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='snapshotRoot', full_name='hadoop.hdfs.SnapshotInfoProto.snapshotRoot', index=1,
      number=2, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='permission', full_name='hadoop.hdfs.SnapshotInfoProto.permission', index=2,
      number=3, type=11, cpp_type=10, label=2,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='owner', full_name='hadoop.hdfs.SnapshotInfoProto.owner', index=3,
      number=4, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='group', full_name='hadoop.hdfs.SnapshotInfoProto.group', index=4,
      number=5, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='createTime', full_name='hadoop.hdfs.SnapshotInfoProto.createTime', index=5,
      number=6, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4737,
  serialized_end=4902,
)

_DATANODEINFOSPROTO.fields_by_name['datanodes'].message_type = _DATANODEINFOPROTO
_DATANODEINFOPROTO.fields_by_name['id'].message_type = _DATANODEIDPROTO
_DATANODEINFOPROTO.fields_by_name['adminState'].enum_type = _DATANODEINFOPROTO_ADMINSTATE
_DATANODEINFOPROTO_ADMINSTATE.containing_type = _DATANODEINFOPROTO
_LOCATEDBLOCKPROTO.fields_by_name['b'].message_type = _EXTENDEDBLOCKPROTO
_LOCATEDBLOCKPROTO.fields_by_name['locs'].message_type = _DATANODEINFOPROTO
_LOCATEDBLOCKPROTO.fields_by_name['blockToken'].message_type = Security__pb2._TOKENPROTO
_LOCATEDBLOCKSPROTO.fields_by_name['blocks'].message_type = _LOCATEDBLOCKPROTO
_LOCATEDBLOCKSPROTO.fields_by_name['lastBlock'].message_type = _LOCATEDBLOCKPROTO
_HDFSFILESTATUSPROTO.fields_by_name['fileType'].enum_type = _HDFSFILESTATUSPROTO_FILETYPE
_HDFSFILESTATUSPROTO.fields_by_name['permission'].message_type = _FSPERMISSIONPROTO
_HDFSFILESTATUSPROTO.fields_by_name['locations'].message_type = _LOCATEDBLOCKSPROTO
_HDFSFILESTATUSPROTO_FILETYPE.containing_type = _HDFSFILESTATUSPROTO
_FSSERVERDEFAULTSPROTO.fields_by_name['checksumType'].enum_type = _CHECKSUMTYPEPROTO
_DIRECTORYLISTINGPROTO.fields_by_name['partialListing'].message_type = _HDFSFILESTATUSPROTO
_SNAPSHOTTABLEDIRECTORYSTATUSPROTO.fields_by_name['dirStatus'].message_type = _HDFSFILESTATUSPROTO
_SNAPSHOTTABLEDIRECTORYLISTINGPROTO.fields_by_name['snapshottableDirListing'].message_type = _SNAPSHOTTABLEDIRECTORYSTATUSPROTO
_SNAPSHOTDIFFREPORTPROTO.fields_by_name['diffReportEntries'].message_type = _SNAPSHOTDIFFREPORTENTRYPROTO
_NAMENODEREGISTRATIONPROTO.fields_by_name['storageInfo'].message_type = _STORAGEINFOPROTO
_NAMENODEREGISTRATIONPROTO.fields_by_name['role'].enum_type = _NAMENODEREGISTRATIONPROTO_NAMENODEROLEPROTO
_NAMENODEREGISTRATIONPROTO_NAMENODEROLEPROTO.containing_type = _NAMENODEREGISTRATIONPROTO
_CHECKPOINTSIGNATUREPROTO.fields_by_name['storageInfo'].message_type = _STORAGEINFOPROTO
_NAMENODECOMMANDPROTO.fields_by_name['type'].enum_type = _NAMENODECOMMANDPROTO_TYPE
_NAMENODECOMMANDPROTO.fields_by_name['checkpointCmd'].message_type = _CHECKPOINTCOMMANDPROTO
_NAMENODECOMMANDPROTO_TYPE.containing_type = _NAMENODECOMMANDPROTO
_CHECKPOINTCOMMANDPROTO.fields_by_name['signature'].message_type = _CHECKPOINTSIGNATUREPROTO
_BLOCKWITHLOCATIONSPROTO.fields_by_name['block'].message_type = _BLOCKPROTO
_BLOCKSWITHLOCATIONSPROTO.fields_by_name['blocks'].message_type = _BLOCKWITHLOCATIONSPROTO
_REMOTEEDITLOGMANIFESTPROTO.fields_by_name['logs'].message_type = _REMOTEEDITLOGPROTO
_NAMESPACEINFOPROTO.fields_by_name['storageInfo'].message_type = _STORAGEINFOPROTO
_EXPORTEDBLOCKKEYSPROTO.fields_by_name['currentKey'].message_type = _BLOCKKEYPROTO
_EXPORTEDBLOCKKEYSPROTO.fields_by_name['allKeys'].message_type = _BLOCKKEYPROTO
_RECOVERINGBLOCKPROTO.fields_by_name['block'].message_type = _LOCATEDBLOCKPROTO
_VERSIONRESPONSEPROTO.fields_by_name['info'].message_type = _NAMESPACEINFOPROTO
_SNAPSHOTINFOPROTO.fields_by_name['permission'].message_type = _FSPERMISSIONPROTO
DESCRIPTOR.message_types_by_name['ExtendedBlockProto'] = _EXTENDEDBLOCKPROTO
DESCRIPTOR.message_types_by_name['DatanodeIDProto'] = _DATANODEIDPROTO
DESCRIPTOR.message_types_by_name['DatanodeInfosProto'] = _DATANODEINFOSPROTO
DESCRIPTOR.message_types_by_name['DatanodeInfoProto'] = _DATANODEINFOPROTO
DESCRIPTOR.message_types_by_name['ContentSummaryProto'] = _CONTENTSUMMARYPROTO
DESCRIPTOR.message_types_by_name['CorruptFileBlocksProto'] = _CORRUPTFILEBLOCKSPROTO
DESCRIPTOR.message_types_by_name['FsPermissionProto'] = _FSPERMISSIONPROTO
DESCRIPTOR.message_types_by_name['LocatedBlockProto'] = _LOCATEDBLOCKPROTO
DESCRIPTOR.message_types_by_name['DataEncryptionKeyProto'] = _DATAENCRYPTIONKEYPROTO
DESCRIPTOR.message_types_by_name['LocatedBlocksProto'] = _LOCATEDBLOCKSPROTO
DESCRIPTOR.message_types_by_name['HdfsFileStatusProto'] = _HDFSFILESTATUSPROTO
DESCRIPTOR.message_types_by_name['FsServerDefaultsProto'] = _FSSERVERDEFAULTSPROTO
DESCRIPTOR.message_types_by_name['DirectoryListingProto'] = _DIRECTORYLISTINGPROTO
DESCRIPTOR.message_types_by_name['SnapshottableDirectoryStatusProto'] = _SNAPSHOTTABLEDIRECTORYSTATUSPROTO
DESCRIPTOR.message_types_by_name['SnapshottableDirectoryListingProto'] = _SNAPSHOTTABLEDIRECTORYLISTINGPROTO
DESCRIPTOR.message_types_by_name['SnapshotDiffReportEntryProto'] = _SNAPSHOTDIFFREPORTENTRYPROTO
DESCRIPTOR.message_types_by_name['SnapshotDiffReportProto'] = _SNAPSHOTDIFFREPORTPROTO
DESCRIPTOR.message_types_by_name['StorageInfoProto'] = _STORAGEINFOPROTO
DESCRIPTOR.message_types_by_name['NamenodeRegistrationProto'] = _NAMENODEREGISTRATIONPROTO
DESCRIPTOR.message_types_by_name['CheckpointSignatureProto'] = _CHECKPOINTSIGNATUREPROTO
DESCRIPTOR.message_types_by_name['NamenodeCommandProto'] = _NAMENODECOMMANDPROTO
DESCRIPTOR.message_types_by_name['CheckpointCommandProto'] = _CHECKPOINTCOMMANDPROTO
DESCRIPTOR.message_types_by_name['BlockProto'] = _BLOCKPROTO
DESCRIPTOR.message_types_by_name['BlockWithLocationsProto'] = _BLOCKWITHLOCATIONSPROTO
DESCRIPTOR.message_types_by_name['BlocksWithLocationsProto'] = _BLOCKSWITHLOCATIONSPROTO
DESCRIPTOR.message_types_by_name['RemoteEditLogProto'] = _REMOTEEDITLOGPROTO
DESCRIPTOR.message_types_by_name['RemoteEditLogManifestProto'] = _REMOTEEDITLOGMANIFESTPROTO
DESCRIPTOR.message_types_by_name['NamespaceInfoProto'] = _NAMESPACEINFOPROTO
DESCRIPTOR.message_types_by_name['BlockKeyProto'] = _BLOCKKEYPROTO
DESCRIPTOR.message_types_by_name['ExportedBlockKeysProto'] = _EXPORTEDBLOCKKEYSPROTO
DESCRIPTOR.message_types_by_name['RecoveringBlockProto'] = _RECOVERINGBLOCKPROTO
DESCRIPTOR.message_types_by_name['VersionRequestProto'] = _VERSIONREQUESTPROTO
DESCRIPTOR.message_types_by_name['VersionResponseProto'] = _VERSIONRESPONSEPROTO
DESCRIPTOR.message_types_by_name['SnapshotInfoProto'] = _SNAPSHOTINFOPROTO
DESCRIPTOR.enum_types_by_name['ChecksumTypeProto'] = _CHECKSUMTYPEPROTO
DESCRIPTOR.enum_types_by_name['ReplicaStateProto'] = _REPLICASTATEPROTO

ExtendedBlockProto = _reflection.GeneratedProtocolMessageType('ExtendedBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _EXTENDEDBLOCKPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ExtendedBlockProto)
  ))
_sym_db.RegisterMessage(ExtendedBlockProto)

DatanodeIDProto = _reflection.GeneratedProtocolMessageType('DatanodeIDProto', (_message.Message,), dict(
  DESCRIPTOR = _DATANODEIDPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DatanodeIDProto)
  ))
_sym_db.RegisterMessage(DatanodeIDProto)

DatanodeInfosProto = _reflection.GeneratedProtocolMessageType('DatanodeInfosProto', (_message.Message,), dict(
  DESCRIPTOR = _DATANODEINFOSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DatanodeInfosProto)
  ))
_sym_db.RegisterMessage(DatanodeInfosProto)

DatanodeInfoProto = _reflection.GeneratedProtocolMessageType('DatanodeInfoProto', (_message.Message,), dict(
  DESCRIPTOR = _DATANODEINFOPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DatanodeInfoProto)
  ))
_sym_db.RegisterMessage(DatanodeInfoProto)

ContentSummaryProto = _reflection.GeneratedProtocolMessageType('ContentSummaryProto', (_message.Message,), dict(
  DESCRIPTOR = _CONTENTSUMMARYPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ContentSummaryProto)
  ))
_sym_db.RegisterMessage(ContentSummaryProto)

CorruptFileBlocksProto = _reflection.GeneratedProtocolMessageType('CorruptFileBlocksProto', (_message.Message,), dict(
  DESCRIPTOR = _CORRUPTFILEBLOCKSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CorruptFileBlocksProto)
  ))
_sym_db.RegisterMessage(CorruptFileBlocksProto)

FsPermissionProto = _reflection.GeneratedProtocolMessageType('FsPermissionProto', (_message.Message,), dict(
  DESCRIPTOR = _FSPERMISSIONPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FsPermissionProto)
  ))
_sym_db.RegisterMessage(FsPermissionProto)

LocatedBlockProto = _reflection.GeneratedProtocolMessageType('LocatedBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDBLOCKPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.LocatedBlockProto)
  ))
_sym_db.RegisterMessage(LocatedBlockProto)

DataEncryptionKeyProto = _reflection.GeneratedProtocolMessageType('DataEncryptionKeyProto', (_message.Message,), dict(
  DESCRIPTOR = _DATAENCRYPTIONKEYPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DataEncryptionKeyProto)
  ))
_sym_db.RegisterMessage(DataEncryptionKeyProto)

LocatedBlocksProto = _reflection.GeneratedProtocolMessageType('LocatedBlocksProto', (_message.Message,), dict(
  DESCRIPTOR = _LOCATEDBLOCKSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.LocatedBlocksProto)
  ))
_sym_db.RegisterMessage(LocatedBlocksProto)

HdfsFileStatusProto = _reflection.GeneratedProtocolMessageType('HdfsFileStatusProto', (_message.Message,), dict(
  DESCRIPTOR = _HDFSFILESTATUSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.HdfsFileStatusProto)
  ))
_sym_db.RegisterMessage(HdfsFileStatusProto)

FsServerDefaultsProto = _reflection.GeneratedProtocolMessageType('FsServerDefaultsProto', (_message.Message,), dict(
  DESCRIPTOR = _FSSERVERDEFAULTSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.FsServerDefaultsProto)
  ))
_sym_db.RegisterMessage(FsServerDefaultsProto)

DirectoryListingProto = _reflection.GeneratedProtocolMessageType('DirectoryListingProto', (_message.Message,), dict(
  DESCRIPTOR = _DIRECTORYLISTINGPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.DirectoryListingProto)
  ))
_sym_db.RegisterMessage(DirectoryListingProto)

SnapshottableDirectoryStatusProto = _reflection.GeneratedProtocolMessageType('SnapshottableDirectoryStatusProto', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTTABLEDIRECTORYSTATUSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SnapshottableDirectoryStatusProto)
  ))
_sym_db.RegisterMessage(SnapshottableDirectoryStatusProto)

SnapshottableDirectoryListingProto = _reflection.GeneratedProtocolMessageType('SnapshottableDirectoryListingProto', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTTABLEDIRECTORYLISTINGPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SnapshottableDirectoryListingProto)
  ))
_sym_db.RegisterMessage(SnapshottableDirectoryListingProto)

SnapshotDiffReportEntryProto = _reflection.GeneratedProtocolMessageType('SnapshotDiffReportEntryProto', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTDIFFREPORTENTRYPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SnapshotDiffReportEntryProto)
  ))
_sym_db.RegisterMessage(SnapshotDiffReportEntryProto)

SnapshotDiffReportProto = _reflection.GeneratedProtocolMessageType('SnapshotDiffReportProto', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTDIFFREPORTPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SnapshotDiffReportProto)
  ))
_sym_db.RegisterMessage(SnapshotDiffReportProto)

StorageInfoProto = _reflection.GeneratedProtocolMessageType('StorageInfoProto', (_message.Message,), dict(
  DESCRIPTOR = _STORAGEINFOPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.StorageInfoProto)
  ))
_sym_db.RegisterMessage(StorageInfoProto)

NamenodeRegistrationProto = _reflection.GeneratedProtocolMessageType('NamenodeRegistrationProto', (_message.Message,), dict(
  DESCRIPTOR = _NAMENODEREGISTRATIONPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.NamenodeRegistrationProto)
  ))
_sym_db.RegisterMessage(NamenodeRegistrationProto)

CheckpointSignatureProto = _reflection.GeneratedProtocolMessageType('CheckpointSignatureProto', (_message.Message,), dict(
  DESCRIPTOR = _CHECKPOINTSIGNATUREPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CheckpointSignatureProto)
  ))
_sym_db.RegisterMessage(CheckpointSignatureProto)

NamenodeCommandProto = _reflection.GeneratedProtocolMessageType('NamenodeCommandProto', (_message.Message,), dict(
  DESCRIPTOR = _NAMENODECOMMANDPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.NamenodeCommandProto)
  ))
_sym_db.RegisterMessage(NamenodeCommandProto)

CheckpointCommandProto = _reflection.GeneratedProtocolMessageType('CheckpointCommandProto', (_message.Message,), dict(
  DESCRIPTOR = _CHECKPOINTCOMMANDPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.CheckpointCommandProto)
  ))
_sym_db.RegisterMessage(CheckpointCommandProto)

BlockProto = _reflection.GeneratedProtocolMessageType('BlockProto', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BlockProto)
  ))
_sym_db.RegisterMessage(BlockProto)

BlockWithLocationsProto = _reflection.GeneratedProtocolMessageType('BlockWithLocationsProto', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKWITHLOCATIONSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BlockWithLocationsProto)
  ))
_sym_db.RegisterMessage(BlockWithLocationsProto)

BlocksWithLocationsProto = _reflection.GeneratedProtocolMessageType('BlocksWithLocationsProto', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKSWITHLOCATIONSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BlocksWithLocationsProto)
  ))
_sym_db.RegisterMessage(BlocksWithLocationsProto)

RemoteEditLogProto = _reflection.GeneratedProtocolMessageType('RemoteEditLogProto', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEEDITLOGPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RemoteEditLogProto)
  ))
_sym_db.RegisterMessage(RemoteEditLogProto)

RemoteEditLogManifestProto = _reflection.GeneratedProtocolMessageType('RemoteEditLogManifestProto', (_message.Message,), dict(
  DESCRIPTOR = _REMOTEEDITLOGMANIFESTPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RemoteEditLogManifestProto)
  ))
_sym_db.RegisterMessage(RemoteEditLogManifestProto)

NamespaceInfoProto = _reflection.GeneratedProtocolMessageType('NamespaceInfoProto', (_message.Message,), dict(
  DESCRIPTOR = _NAMESPACEINFOPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.NamespaceInfoProto)
  ))
_sym_db.RegisterMessage(NamespaceInfoProto)

BlockKeyProto = _reflection.GeneratedProtocolMessageType('BlockKeyProto', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKKEYPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.BlockKeyProto)
  ))
_sym_db.RegisterMessage(BlockKeyProto)

ExportedBlockKeysProto = _reflection.GeneratedProtocolMessageType('ExportedBlockKeysProto', (_message.Message,), dict(
  DESCRIPTOR = _EXPORTEDBLOCKKEYSPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.ExportedBlockKeysProto)
  ))
_sym_db.RegisterMessage(ExportedBlockKeysProto)

RecoveringBlockProto = _reflection.GeneratedProtocolMessageType('RecoveringBlockProto', (_message.Message,), dict(
  DESCRIPTOR = _RECOVERINGBLOCKPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.RecoveringBlockProto)
  ))
_sym_db.RegisterMessage(RecoveringBlockProto)

VersionRequestProto = _reflection.GeneratedProtocolMessageType('VersionRequestProto', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONREQUESTPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.VersionRequestProto)
  ))
_sym_db.RegisterMessage(VersionRequestProto)

VersionResponseProto = _reflection.GeneratedProtocolMessageType('VersionResponseProto', (_message.Message,), dict(
  DESCRIPTOR = _VERSIONRESPONSEPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.VersionResponseProto)
  ))
_sym_db.RegisterMessage(VersionResponseProto)

SnapshotInfoProto = _reflection.GeneratedProtocolMessageType('SnapshotInfoProto', (_message.Message,), dict(
  DESCRIPTOR = _SNAPSHOTINFOPROTO,
  __module__ = 'hdfs_pb2'
  # @@protoc_insertion_point(class_scope:hadoop.hdfs.SnapshotInfoProto)
  ))
_sym_db.RegisterMessage(SnapshotInfoProto)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('\n%org.apache.hadoop.hdfs.protocol.protoB\nHdfsProtos\240\001\001'))
# @@protoc_insertion_point(module_scope)
